@@ -1,20 +1,18 @@
 /* tree.c -- helper functions to build and evaluate the expression tree.
    Copyright (C) 1990, 91, 92, 93, 94, 2000, 2003, 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <config.h>
@@ -828,7 +826,7 @@ set_new_parent (struct predicate *curr, enum predicate_precedence high_prec, str
 {
   struct predicate *new_parent;
 
-  new_parent = (struct predicate *) xmalloc (sizeof (struct predicate));
+  new_parent = xmalloc (sizeof (struct predicate));
   new_parent->p_type = BI_OP;
   new_parent->p_prec = high_prec;
   new_parent->need_stat = false;
@@ -893,7 +891,7 @@ merge_pred (struct predicate *beg_list, struct predicate *end_list, struct predi
 
 struct pred_cost_lookup
 {
-  PRED_FUNC 		fn;
+  PRED_FUNC             fn;
   enum EvaluationCost   cost;
 };
 static struct pred_cost_lookup costlookup[] = 
@@ -971,13 +969,7 @@ check_sorted(void *base, size_t members, size_t membersize,
       if (result < 0)
 	return false;
       result = cmpfn(p+(i-1)*membersize, p+i*membersize);
-      assert(result <= 0);
-    }
-  for (i=1u; i<members; ++i)
-    {
-      const struct pred_cost_lookup *pl1 = (const struct pred_cost_lookup*)(p+(i-1)*membersize);
-      const struct pred_cost_lookup *pl2 = (const struct pred_cost_lookup*)(p+(i-0)*membersize);
-      assert(pl1->fn <= pl2->fn);
+      assert (result <= 0);
     }
   return true;
 }
@@ -986,16 +978,20 @@ check_sorted(void *base, size_t members, size_t membersize,
 static int
 cost_table_comparison(const void *p1, const void *p2)
 {
+  /* We have to compare the function pointers with memcmp(), 
+   * because ISO C does not allow magnitude comparison of 
+   * function pointers (just equality testing).
+   */
   const struct pred_cost_lookup *pc1 = p1;
   const struct pred_cost_lookup *pc2 = p2;
-  
-  
-  if (pc1->fn == pc2->fn)
-    return 0;
-  else if (pc1->fn > pc2->fn)
-    return 1;
-  else
-    return -1;
+  union {
+    PRED_FUNC pfn;
+    char mem[sizeof (PRED_FUNC)];
+  } u1, u2;
+
+  u1.pfn = pc1->fn;
+  u2.pfn = pc2->fn;
+  return memcmp(u1.mem, u2.mem, sizeof(u1.pfn));
 }
 
 static enum EvaluationCost
@@ -1046,7 +1042,7 @@ get_pred_cost(const struct predicate *p)
 			    sizeof(costlookup[0]),
 			    cost_table_comparison))
 	    {
-	      error(1, 0, "Failed to sort the costlookup array.");
+	      error(1, 0, "Failed to sort the costlookup array (indirect).");
 	    }
 	  pred_table_sorted = 1;
 	}
@@ -1103,32 +1099,32 @@ getrate(const struct predicate *p)
 float 
 calculate_derived_rates(struct predicate *p)
 {
-  assert(NULL != p);
+  assert (NULL != p);
 
   if (p->pred_right)
     calculate_derived_rates(p->pred_right);
   if (p->pred_left)
     calculate_derived_rates(p->pred_left);
 
-  assert(p->p_type != CLOSE_PAREN);
-  assert(p->p_type != OPEN_PAREN);
+  assert (p->p_type != CLOSE_PAREN);
+  assert (p->p_type != OPEN_PAREN);
 
   switch (p->p_type)
     {
     case NO_TYPE:
-      assert(NULL == p->pred_right);
-      assert(NULL == p->pred_left);
+      assert (NULL == p->pred_right);
+      assert (NULL == p->pred_left);
       return p->est_success_rate;
       
     case PRIMARY_TYPE:
-      assert(NULL == p->pred_right);
-      assert(NULL == p->pred_left);
+      assert (NULL == p->pred_right);
+      assert (NULL == p->pred_left);
       return p->est_success_rate;
 
     case UNI_OP:
       /* Unary operators must have exactly one operand */
-      assert(pred_is(p, pred_negate));
-      assert(NULL == p->pred_left);
+      assert (pred_is(p, pred_negate));
+      assert (NULL == p->pred_left);
       p->est_success_rate = (1.0 - p->pred_right->est_success_rate);
       return p->est_success_rate;
 
@@ -1151,8 +1147,8 @@ calculate_derived_rates(struct predicate *p)
 	else
 	  {
 	    /* only and, or and comma are BI_OP. */
-	    assert(0);
-	    rate = 0.0f;
+	    assert (0);
+	    abort ();
 	  }
 	p->est_success_rate = constrain_rate(rate);
       }
@@ -1163,6 +1159,8 @@ calculate_derived_rates(struct predicate *p)
       p->est_success_rate = 1.0;
       return p->est_success_rate;
     }
+  assert (0);
+  abort ();
 }
 
 /* opt_expr() rearranges predicates such that each left subtree is
@@ -1174,12 +1172,12 @@ static void check_normalization(struct predicate *p, boolean at_root)
 {
   if (at_root)
     {
-      assert(BI_OP == p->p_type);
+      assert (BI_OP == p->p_type);
     }
 
   if (p->pred_left)
     {
-      assert(BI_OP == p->pred_left->p_type);
+      assert (BI_OP == p->pred_left->p_type);
       check_normalization(p->pred_left, false);
     }
   if (p->pred_right)
@@ -1212,9 +1210,9 @@ build_expression_tree(int argc, char *argv[], int end_of_leading_options)
   entry_open  = find_parser("(");
   entry_close = find_parser(")");
   entry_print = find_parser("print");
-  assert(entry_open  != NULL);
-  assert(entry_close != NULL);
-  assert(entry_print != NULL);
+  assert (entry_open  != NULL);
+  assert (entry_close != NULL);
+  assert (entry_print != NULL);
   
   parse_openparen (entry_open, argv, &argc);
   last_pred->p_name = "(";
@@ -1291,7 +1289,7 @@ build_expression_tree(int argc, char *argv[], int end_of_leading_options)
 	 were given; remove the unneeded initial `(' and add `-print'. */
       cur_pred = predicates;
       predicates = last_pred = predicates->pred_next;
-      free ((char *) cur_pred);
+      free (cur_pred);
       parse_print (entry_print, argv, &argc);
       last_pred->p_name = "-print";
       pred_sanity_check(last_pred); 
@@ -1304,7 +1302,7 @@ build_expression_tree(int argc, char *argv[], int end_of_leading_options)
       cur_pred = predicates;
       predicates = predicates->pred_next;
       pred_sanity_check(predicates); /* XXX: expensive */
-      free ((char *) cur_pred);
+      free (cur_pred);
     }
   else
     {
@@ -1410,8 +1408,8 @@ get_new_pred (const struct parser_table *entry)
   (void) entry;
 
   /* Options should not be turned into predicates. */
-  assert(entry->type != ARG_OPTION);
-  assert(entry->type != ARG_POSITIONAL_OPTION);
+  assert (entry->type != ARG_OPTION);
+  assert (entry->type != ARG_POSITIONAL_OPTION);
   
   if (predicates == NULL)
     {
@@ -1421,7 +1419,7 @@ get_new_pred (const struct parser_table *entry)
     }
   else
     {
-      new_pred = (struct predicate *) xmalloc (sizeof (struct predicate));
+      new_pred = xmalloc (sizeof (struct predicate));
       last_pred->pred_next = new_pred;
       last_pred = new_pred;
     }
@@ -1460,7 +1458,7 @@ get_new_pred_chk_op (const struct parser_table *entry)
     entry_and = find_parser("and");
 
   /* Check that it's actually there. If not, that is a bug.*/
-  assert(entry_and != NULL);	
+  assert (entry_and != NULL);	
 
   if (last_pred)
     switch (last_pred->p_type)
