@@ -1,30 +1,24 @@
 /* util.c -- functions for initializing new tree elements, and other things.
    Copyright (C) 1990, 91, 92, 93, 94, 2000, 2003, 2004, 2005 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <config.h>
 #include "defs.h"
 
-#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
-#else
-#include <sys/file.h>
-#endif
 #ifdef HAVE_SYS_UTSNAME_H
 #include <sys/utsname.h>
 #endif
@@ -125,7 +119,7 @@ insert_primary_withpred (const struct parser_table *entry, PRED_FUNC pred_func)
 struct predicate *
 insert_primary (const struct parser_table *entry)
 {
-  assert(entry->pred_func != NULL);
+  assert (entry->pred_func != NULL);
   return insert_primary_withpred(entry, entry->pred_func);
 }
 
@@ -252,7 +246,7 @@ get_info (const char *pathname,
 
 /* Determine if we can use O_NOFOLLOW.
  */
-#if defined(O_NOFOLLOW)
+#if defined O_NOFOLLOW
 boolean 
 check_nofollow(void)
 {
@@ -299,7 +293,7 @@ do_complete_pending_execdirs(struct predicate *p, int dirfd)
   if (NULL == p)
     return;
   
-  assert(state.execdirs_outstanding);
+  assert (state.execdirs_outstanding);
   
   do_complete_pending_execdirs(p->pred_left, dirfd);
   
@@ -439,7 +433,7 @@ cleanup(void)
  * system call is itself returning 0 in this case). 
  */
 #undef DEBUG_SV_BUG_16378
-#if defined(DEBUG_SV_BUG_16378)
+#if defined DEBUG_SV_BUG_16378
 static int hook_fstatat(int fd, const char *name, struct stat *p, int flags)
 {
   static int warned = 0;
@@ -524,7 +518,7 @@ int
 optionh_stat(const char *name, struct stat *p)
 {
   if (AT_FDCWD != state.cwd_dir_fd)
-    assert(state.cwd_dir_fd >= 0);
+    assert (state.cwd_dir_fd >= 0);
   set_stat_placeholders(p);
   if (0 == state.curdepth) 
     {
@@ -555,7 +549,7 @@ optionl_stat(const char *name, struct stat *p)
 {
   int rv;
   if (AT_FDCWD != state.cwd_dir_fd)
-    assert(state.cwd_dir_fd >= 0);
+    assert (state.cwd_dir_fd >= 0);
   
   set_stat_placeholders(p);
   rv = fstatat(state.cwd_dir_fd, name, p, 0);
@@ -572,7 +566,7 @@ optionl_stat(const char *name, struct stat *p)
 int 
 optionp_stat(const char *name, struct stat *p)
 {
-  assert((state.cwd_dir_fd >= 0) || (state.cwd_dir_fd==AT_FDCWD));
+  assert ((state.cwd_dir_fd >= 0) || (state.cwd_dir_fd==AT_FDCWD));
   set_stat_placeholders(p);
   return fstatat(state.cwd_dir_fd, name, p, AT_SYMLINK_NOFOLLOW);
 }
@@ -596,7 +590,7 @@ debug_stat (const char *file, struct stat *bufp)
       return optionp_stat(file, bufp);
     }
   /*NOTREACHED*/
-  assert(false);
+  assert (0);
   return -1;
 }
 
@@ -885,7 +879,7 @@ now(void)
       return retval;
     }
   t = time(NULL);
-  assert(t != (time_t)-1);
+  assert (t != (time_t)-1);
   retval.tv_sec = t;
   retval.tv_nsec = 0;
   return retval;
