@@ -1,26 +1,25 @@
 /* xargs -- build and execute command lines from standard input
-   Copyright (C) 1990, 91, 92, 93, 94, 2000, 2003, 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1990, 91, 92, 93, 94, 2000, 2003, 2004, 2005, 2006,
+   2007 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* Written by Mike Rendell <michael@cs.mun.ca>
    and David MacKenzie <djm@gnu.org>.  
    Modifications by 
-   	James Youngman
+        James Youngman
 	Dmitry V. Levin
 */
 
@@ -58,13 +57,13 @@
 #include <getopt.h>
 #include <fcntl.h>
 
-#if defined(STDC_HEADERS)
+#if defined STDC_HEADERS
 #include <assert.h>
 #endif
 
-#if defined(HAVE_STRING_H) || defined(STDC_HEADERS)
+#if defined HAVE_STRING_H || defined STDC_HEADERS
 #include <string.h>
-#if !defined(STDC_HEADERS)
+#if !defined STDC_HEADERS
 #include <memory.h>
 #endif
 #else
@@ -95,8 +94,10 @@
 #define SIGCHLD SIGCLD
 #endif
 
+#include "verify.h"
 #include "wait.h"
 #include "quotearg.h"
+#include "findutils-version.h"
 
 
 #ifdef STDC_HEADERS
@@ -163,7 +164,7 @@ typedef int boolean;
 #endif
 
 #include <xalloc.h>
-#include "closeout.h"
+#include "closein.h"
 #include "gnulib-version.h"
 
 void error PARAMS ((int status, int errnum, char *message,...));
@@ -281,7 +282,7 @@ get_char_oct_or_hex_escape(const char *s)
   unsigned long val;
   char *endp;
 
-  assert('\\' == s[0]);
+  assert ('\\' == s[0]);
   
   if ('x' == s[1])
     {
@@ -419,7 +420,7 @@ main (int argc, char **argv)
 #endif
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
-  atexit (close_stdout);
+  atexit (close_stdin);
   atexit (wait_for_proc_all);
 
   /* xargs is required by POSIX to allow 2048 bytes of headroom 
@@ -470,17 +471,17 @@ main (int argc, char **argv)
 	  /* Note that val can in fact be greater than ARG_MAX
 	   * and bc_ctl.arg_max can also be greater than ARG_MAX.
 	   */
-	  assert(bc_ctl.arg_max <= (val-XARGS_POSIX_HEADROOM));
+	  assert (bc_ctl.arg_max <= (val-XARGS_POSIX_HEADROOM));
 	}
       else
 	{
-# if defined(ARG_MAX)
-	  assert(bc_ctl.arg_max <= (ARG_MAX-XARGS_POSIX_HEADROOM));
+# if defined ARG_MAX
+	  assert (bc_ctl.arg_max <= (ARG_MAX-XARGS_POSIX_HEADROOM));
 # endif
 	}
 #else
       /* No _SC_ARG_MAX */
-      assert(bc_ctl.arg_max <= (ARG_MAX-XARGS_POSIX_HEADROOM));
+      assert (bc_ctl.arg_max <= (ARG_MAX-XARGS_POSIX_HEADROOM));
 #endif
 
 
@@ -489,7 +490,7 @@ main (int argc, char **argv)
        * conforms to the POSIX requirement that the default command
        * line length shall be at least LINE_MAX.
        */
-      assert(bc_ctl.arg_max >= LINE_MAX);
+      assert (bc_ctl.arg_max >= LINE_MAX);
 #endif
       
       bc_ctl.exec_callback = xargs_do_exec;
@@ -618,8 +619,7 @@ main (int argc, char **argv)
           break;
 
 	case 'v':
-	  printf (_("GNU xargs version %s\n"), version_string);
-	  printf (_("Built using GNU gnulib version %s\n"), gnulib_version);
+	  display_findutils_version("xargs");
 	  return 0;
 
 	default:
@@ -636,7 +636,7 @@ main (int argc, char **argv)
    * the environment is too large. 
    */
   act_on_init_result();
-  assert(BC_INIT_OK == bcstatus);
+  assert (BC_INIT_OK == bcstatus);
 
   if (0 == strcmp (input_file, "-"))
     {
@@ -671,7 +671,7 @@ main (int argc, char **argv)
    * special C99 ways to print such values.  Unfortunately this
    * program tries to work on both C89 and C99 systems.
    */
-#if defined(SIZE_MAX)
+#if defined SIZE_MAX
 # if SIZE_MAX > ULONG_MAX
 # error "I'm not sure how to print size_t values on your system"
 # endif
@@ -679,7 +679,7 @@ main (int argc, char **argv)
   /* Without SIZE_MAX (i.e. limits.h) this is probably 
    * close to the best we can do.
    */
-  assert(sizeof(size_t) <= sizeof(unsigned long));
+  verify_true (sizeof(size_t) <= sizeof(unsigned long));
 #endif
   
   if (show_limits)
@@ -720,8 +720,8 @@ main (int argc, char **argv)
 	}
     }
   
-  linebuf = (char *) xmalloc (bc_ctl.arg_max + 1);
-  bc_state.argbuf = (char *) xmalloc (bc_ctl.arg_max + 1);
+  linebuf = xmalloc (bc_ctl.arg_max + 1);
+  bc_state.argbuf = xmalloc (bc_ctl.arg_max + 1);
 
   /* Make sure to listen for the kids.  */
   signal (SIGCHLD, SIG_DFL);
@@ -755,7 +755,7 @@ main (int argc, char **argv)
     {
       int i;
       size_t len;
-      size_t *arglen = (size_t *) xmalloc (sizeof (size_t) * argc);
+      size_t *arglen = xmalloc (sizeof (size_t) * argc);
 
       for (i = optind; i < argc; i++)
 	arglen[i] = strlen(argv[i]);
@@ -1159,13 +1159,13 @@ add_proc (pid_t pid)
       if (pids_alloc == 0)
 	{
 	  pids_alloc = proc_max ? proc_max : 64;
-	  pids = (pid_t *) xmalloc (sizeof (pid_t) * pids_alloc);
+	  pids = xmalloc (sizeof (pid_t) * pids_alloc);
 	}
       else
 	{
 	  pids_alloc *= 2;
-	  pids = (pid_t *) xrealloc (pids,
-				     sizeof (pid_t) * pids_alloc);
+	  pids = xrealloc (pids,
+			   sizeof (pid_t) * pids_alloc);
 	}
       memset (&pids[i], '\0', sizeof (pid_t) * (pids_alloc - i));
     }
